@@ -98,12 +98,14 @@ pub struct ReportResponse {}
 pub mod service_controller_client {
     #![allow(unused_variables, dead_code, missing_docs, clippy::let_unit_value)]
     use tonic::codegen::*;
-    #[doc = " [Service Control API v2](/service-infrastructure/docs/service-control)"]
+    #[doc = " [Service Control API"]
+    #[doc = " v2](https://cloud.google.com/service-infrastructure/docs/service-control/access-control)"]
     #[doc = ""]
     #[doc = " Private Preview. This feature is only available for approved services."]
     #[doc = ""]
     #[doc = " This API provides admission control and telemetry reporting for services"]
-    #[doc = " that are integrated with [Service Infrastructure](/service-infrastructure)."]
+    #[doc = " that are integrated with [Service"]
+    #[doc = " Infrastructure](https://cloud.google.com/service-infrastructure)."]
     #[derive(Debug, Clone)]
     pub struct ServiceControllerClient<T> {
         inner: tonic::client::Grpc<T>,
@@ -152,11 +154,13 @@ pub mod service_controller_client {
         #[doc = " Private Preview. This feature is only available for approved services."]
         #[doc = ""]
         #[doc = " This method provides admission control for services that are integrated"]
-        #[doc = " with [Service Infrastructure](/service-infrastructure). It checks whether"]
-        #[doc = " an operation should be allowed based on the service configuration and"]
-        #[doc = " relevant policies. It must be called before the operation is executed."]
+        #[doc = " with [Service"]
+        #[doc = " Infrastructure](https://cloud.google.com/service-infrastructure). It checks"]
+        #[doc = " whether an operation should be allowed based on the service configuration"]
+        #[doc = " and relevant policies. It must be called before the operation is executed."]
         #[doc = " For more information, see"]
-        #[doc = " [Admission Control](/service-infrastructure/docs/admission-control)."]
+        #[doc = " [Admission"]
+        #[doc = " Control](https://cloud.google.com/service-infrastructure/docs/admission-control)."]
         #[doc = ""]
         #[doc = " NOTE: The admission control has an expected policy propagation delay of"]
         #[doc = " 60s. The caller **must** not depend on the most recent policy changes."]
@@ -188,10 +192,12 @@ pub mod service_controller_client {
         #[doc = " Private Preview. This feature is only available for approved services."]
         #[doc = ""]
         #[doc = " This method provides telemetry reporting for services that are integrated"]
-        #[doc = " with [Service Infrastructure](/service-infrastructure). It reports a list"]
-        #[doc = " of operations that have occurred on a service. It must be called after the"]
-        #[doc = " operations have been executed. For more information, see"]
-        #[doc = " [Telemetry Reporting](/service-infrastructure/docs/telemetry-reporting)."]
+        #[doc = " with [Service"]
+        #[doc = " Infrastructure](https://cloud.google.com/service-infrastructure). It"]
+        #[doc = " reports a list of operations that have occurred on a service. It must be"]
+        #[doc = " called after the operations have been executed. For more information, see"]
+        #[doc = " [Telemetry"]
+        #[doc = " Reporting](https://cloud.google.com/service-infrastructure/docs/telemetry-reporting)."]
         #[doc = ""]
         #[doc = " NOTE: The telemetry reporting has a hard limit of 1000 operations and 1MB"]
         #[doc = " per Report call. It is recommended to have no more than 100 operations per"]
